// Modified 
/*  
   CS 202, Homework#4 
   Problem 2 
   Author: Harish Kumar 
*/
// Fig. 10.18: Time.h
// Cascading member function calls.

// Time class definition.
// Member functions defined in Time.cpp.
#ifndef TIME_H
#define TIME_H

class Time 
{
public:
   Time( int = 0, int = 0, int = 0 ); // default constructor

   // set functions (the Time & return types enable cascading)
   Time &setTime( int, int, int ); // set hour, minute, second
   Time &setHour( int ); // set hour
   Time &setMinute( int ); // set minute
   Time &setSecond( int ); // set second

   // get functions (normally declared const)
   int getHour() const; // return hour
   int getMinute() const; // return minute
   int getSecond() const; // return second

   // print functions (normally declared const)
   void printUniversal() const; // print universal time
   void printStandard() const; // print standard time
private:
   int totalsec; // 0 - 86399
}; // end class Time

#endif


// Modified
/*  
   CS 202, Homework#4 
   Problem 2 
   Author: Harish Kumar 
*/

// Fig. 10.19: Time.cpp 
// Member-function definitions for Time class.
#include <iostream>
using std::cout;

#include <iomanip>
using std::setfill;
using std::setw;

//#include "Time.h" // Time class definition

// constructor function to initialize private data;
// calls member function setTime to set variables;
// default values are 0 (see class definition)
Time::Time( int hr, int min, int sec ) 
{ 
   setTime( hr, min, sec ); 
} // end Time constructor

// set values of hour, minute, and second
Time &Time::setTime( int h, int m, int s ) // note Time & return
{
   setHour( h );
   setMinute( m );
   setSecond( s ); 
   return *this; // enables cascading
} // end function setTime

// set hour value
Time &Time::setHour( int h ) // note Time & return
{
   // validate hour
   totalsec += ( h >= 0 && h < 24 ) ? (h-getHour())*3600 : -getHour()*3600;
   return *this; // enables cascading
}  // end function setHour

// set minute value
Time &Time::setMinute( int m ) // note Time & return
{
   // validate minute
   totalsec += ( m >= 0 && m < 60 ) ? (m-getMinute())*60 : -getMinute()*60;
   return *this; // enables cascading
}  // end function setMinute

// set second value
Time &Time::setSecond( int s ) // note Time & return
{
   // validate second
   totalsec += ( s >= 0 && s < 60 ) ? s-getSecond() : -getSecond();
   return *this; // enables cascading
}  // end function setSecond

// get hour value
int Time::getHour() const 
{ 
   return ( (totalsec/3600) % 24 ); 
} // end function getHour

// get minute value
int Time::getMinute() const 
{ 
   return ( (totalsec/60) % 60 ); 
} // end function getMinute

// get second value
int Time::getSecond() const 
{ 
   return (totalsec % 60); 
} // end function getSecond

// print Time in universal-time format (HH:MM:SS) 
void Time::printUniversal() const
{
   cout << setfill( '0' ) << setw( 2 ) << getHour() << ":"
      << setw( 2 ) << getMinute() << ":" << setw( 2 ) << getSecond();
} // end function printUniversal

// print Time in standard-time format (HH:MM:SS AM or PM)
void Time::printStandard() const
{
   cout << ( ( getHour() == 0 || getHour() == 12 ) ? 12 : getHour() % 12 )
      << ":" << setfill( '0' ) << setw( 2 ) << getMinute()
      << ":" << setw( 2 ) << getSecond() << ( getHour() < 12 ? " AM" : " PM" );
} // end function printStandard


// Unmodified
/*  
   CS 202, Homework#4 
   Problem 2 
   Author: Harish Kumar 
*/
// Fig. 10.20: fig10_20.cpp
// Cascading member function calls with the this pointer.
#include <iostream>
using std::cout;
using std::endl;

//#include "Time.h" // Time class definition

int main()
{
   Time t; // create Time object

   // cascaded function calls
   t.setHour( 18 ).setMinute( 30 ).setSecond( 22 );

   // output time in universal and standard formats
   cout << "Universal time: ";
   t.printUniversal();

   cout << "\nStandard time: ";
   t.printStandard();

   cout << "\n\nNew standard time: ";

   // cascaded function calls
   t.setTime( 20, 20, 20 ).printStandard();
   cout << endl;

   return 0;
} // end main

// OUTPUT

/*
Universal time: 18:30:22 

Standard time: 6:30:22 PM 
 

New standard time: 8:20:20 PM
*/



